ContinuousScanConfig class

Tuning knobs for continuous scanning behaviour.

Constructors

ContinuousScanConfig({Duration rescanDelay = const Duration(seconds: 3), Duration keepAliveInterval = const Duration(seconds: 2), Duration duplicateSuppression = const Duration(milliseconds: 500)})
const

Properties

duplicateSuppression Duration
Ignore identical barcodes received within this window.
final
hashCode int
The hash code for this object.
no setterinherited
keepAliveInterval Duration
How often to re-trigger the hardware scan button while actively scanning.
final
rescanDelay Duration
How long to wait after a successful scan before re-arming the scanner.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited